@@ -20,7 +20,7 @@ class CreateException(ExceptionFactory):
     detail = '创建异常'
 
 
-class NotfoundException(ExceptionFactory):
+class NotFoundException(ExceptionFactory):
     status_code = 404
     detail = '资源不存在'
 
